#!/usr/bin/env bash

#
# Copyright (c) 2007-2010 Backblaze Inc. All rights reserved.
#
# Shout out to Adam Fisk for writing about AppleScript uninstallers!

function die {
    echo $*
    exit 1
}

function remove {
    rm -r "$1" || die "Could not remove file: $1"
}

function shutdown_bzserv {
    local output=`ps -cA | grep bzserv`
    local bz_plist='/Library/LaunchDaemons/com.backblaze.bzserv.plist'
    if [ -n "$output" ]
    then
        test -f $bz_plist && launchctl unload $bz_plist
        test -f $bz_plist && remove $bz_plist
    else
        if [ -f $bz_plist ]
        then
            remove $bz_plist
        fi
    fi
}

function clean_library_backblaze {
    local bz_pkgs='/Library/Backblaze.bzpkg'
    local bz_apps='/Library/Backblaze'
    if [ -d $bz_apps ]
    then
        remove $bz_apps
    fi
    if [ -d $bz_pkgs ]
    then
        remove $bz_pkgs
    fi	
}

function clean_system_preferences_backblaze { 
    local bz_pref_pane='/Library/PreferencePanes/BackblazeBackup.prefPane'
    if [ -d $bz_pref_pane ]
    then
        remove $bz_pref_pane
    fi	
}

function clean_applications_backblaze {
    local bz_app='/Applications/Backblaze.app'
    if [ -d $bz_app ]
    then
        remove $bz_app
    fi
}

function clean_misc {
    local bz_extbx="/Library/Application Support/ExtBX"
    if [ -d "$bz_extbx" ]
    then
        remove "$bz_extbx"
    fi
}

function shutdown_bzbmenu {
    local output=`ps -cA | grep bzbmenu`
    if [ -n "$output" ]
    then
        killall -9 bzbmenu
    fi
}

function restore_ac_powersetting_to_normal {
    bz_victoryfile="/Library/Backblaze/bzdata/bzreports/bzstat_endfirstbackupmillis.txt"
    if [ ! -f $bz_victoryfile ]
    then
        pmset -c sleep 11 &> /dev/null
    fi
}

function unload_bzbmenu {
    for dir in /Users/*
    do
        userName=${dir:7}
        if [ $userName == 'Guest' -o $userName == 'Shared' ]
        then
            continue
        fi
        bzbmenuPlist="$dir/Library/LaunchAgents/com.backblaze.bzbmenu.plist"
        if [ -f "$bzbmenuPlist" ]
        then        
            sudo -u "$userName" launchctl unload "$bzbmenuPlist"
            remove "$bzbmenuPlist"
        fi
    done
}

function bz_main {
    shutdown_bzbmenu	
    shutdown_bzserv
    clean_library_backblaze
    clean_system_preferences_backblaze
    clean_applications_backblaze
    clean_misc
    unload_bzbmenu
}

# main 
bz_main
